# Welcome

`readimc` is a Python package for reading Fluidigm&reg; Imaging Mass Cytometry&trade; files

## Supported file types

  - Fluidigm&reg; MCD&trade;
  - Fluidigm&reg; TXT

## Extractable image data

  - Slide images (user-uploaded)
  - Panorama images (single-channel, color)
  - IMC&trade; acquisitions (multi-channel, grayscale)
  - Before/after-ablation images (single-channel, color)

```{toctree}
:hidden:
:caption: Contents

install
usage
license
changelog
```

```{toctree}
:hidden:
:caption: Development

authors
contributors
contributing
```

```{toctree}
:hidden:
:caption: API documentation

autoapi/readimc/index
```
